#include <ishtar/network.h>
#include <iostream>
#include <cstdlib>

// Simple network client that dumps data from the network
class SimpleNetworkClient : public Ishtar::NetworkClient
{
public:
	// Constructor, just create Ishtar::NetworkClient
	SimpleNetworkClient(const std::string &host, Ishtar::UInt16 port, const std::string &filename) :
		Ishtar::NetworkClient(host, port)
	{
		// Send first line header
		std::string request("GET ");
		request += filename;
		request += " HTTP/1.1\r\n";
		socket->write(request.c_str(), request.length());
		
		// Send second line header
		request = "Host: ";
		request += host;
		request += "\r\n\r\n";
		socket->write(request.c_str(), request.length());
		
		socket->flush();
	}
	
	// Incoming data, print them
	virtual void incomingData (Ishtar::Socket *socket)
	{
		// read and print result, inefficient because we read only one byte at a time
		std::cout << socket->readUInt8();
	}
	
	// Remote host has closed, print its name
	virtual void connectionClosed (Ishtar::Socket *socket)
	{
		std::cout << "Host " << socket->getRemoteName() << " has closed connection." << std::endl;
	}
};

int main(int argc, char *argv[])
{
	// we want the hostname and port as argument
	if (argc != 4)
	{
		std::cerr << "Usage " << argv[0] << " hostname port filename" << std::endl;
		exit(1);
	}
	
	// Create an instance of TCP/IP client
	SimpleNetworkClient client(argv[1], atoi(argv[2]), argv[3]);
	
	// Run the client forever
	client.run();
}