/*
    Ishtar - A network transparent read/write interface with
    probing and enumeration support.
    network part : convenient cross-platform packaging for tcp/ip networking
    Copyright (C) 2003-2005 Stephane Magnenat <nct@ysagoon.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __ISHTAR_FILESTREAM_H
#define __ISHTAR_FILESTREAM_H
 
#include "stream.h"
#include <fstream>

/*!	\file filestream.h
	\brief Interface of file stream backed
*/

namespace Ishtar
{
	//! An output file stream to which we can write
	class FileOutputStream:public Ishtar::OutputStream
	{
	protected:
		std::ofstream stream; //!< underlying c++ file stream
		
	public:
		//! Constructor, open filename in output (or another specified mode)
		FileOutputStream(const std::string &filename, std::ios_base::openmode mode = std::ios_base::out | std::ios_base::trunc );
		virtual ~FileOutputStream();
		virtual void write(const void *data, const Size size);
		virtual void flush(void);
		//! cast to bool operator, returns true if stream is valid
		operator bool () { return static_cast<bool>(stream); }
	};
	
	//! An input file stream from which we can read
	class FileInputStream:public Ishtar::InputStream
	{
	protected:
		std::ifstream stream; //!< underlying c++ file stream
		
	public:
		//! Constructor, open filename in input (or another specified mode)
		FileInputStream(const std::string &filename, std::ios_base::openmode mode = std::ios_base::in );
		virtual ~FileInputStream();
		virtual void read(void *data, Size size);
		//! cast to bool operator, returns true if stream is valid
		operator bool () { return static_cast<bool>(stream); }
	};
}
 
#endif
